@@ -1,8 +1,17 @@
+# webdriver manager
 from je_web_runner.selenium_wrapper.webdriver_manager import get_webdriver_manager
 from je_web_runner.selenium_wrapper.webdriver_with_options import set_webdriver_options_argument
+# test object
 from je_web_runner.test_object.test_object import TestObject
-from je_web_runner.selenium_utils_wrapper.desired_capabilities.desired_capabilities import get_desired_capabilities
-from je_web_runner.selenium_utils_wrapper.desired_capabilities.desired_capabilities import get_desired_capabilities_keys
 from je_web_runner.test_object.test_object import create_test_object
 from je_web_runner.test_object.test_object import get_test_object_type_list
+# selenium utils
+from je_web_runner.selenium_utils_wrapper.desired_capabilities.desired_capabilities import get_desired_capabilities
+from je_web_runner.selenium_utils_wrapper.desired_capabilities.desired_capabilities import get_desired_capabilities_keys
+# utils
 from je_web_runner.utils.executor.executor import execute_action
+# webdriver wrapper
+from je_web_runner.selenium_wrapper.webdriver_wrapper import webdriver_wrapper
+# web element
+from je_web_runner.selenium_wrapper.web_element_wrapper import web_element_wrapper
+
