@@ -14,10 +14,10 @@ from selenium.webdriver.edge.service import Service
 from selenium.webdriver.ie.service import Service
 from selenium.webdriver.safari.service import Service
 
-from je_web_runner.selenium_wrapper import webdriver_manager
 from je_web_runner.test_object.test_object import TestObject
 
 from je_web_runner.selenium_wrapper.webdriver_with_options import set_webdriver_options_capability_wrapper
+from je_web_runner.utils.assert_value.result_check import check_result
 from je_web_runner.utils.exception.exceptions import WebDriverException, WebDriverIsNoneException
 from je_web_runner.utils.exception.exceptions import WebDriverNotFoundException
 
@@ -96,12 +96,16 @@ class WebDriverWrapper(object):
     def find_element(self, test_object: TestObject):
         if self.current_webdriver is None:
             raise WebDriverIsNoneException(selenium_wrapper_web_driver_not_found_error)
-        return self.current_webdriver.find_element(test_object.test_object_type, test_object.test_object_name)
+        web_element_wrapper.current_web_element = self.current_webdriver.find_element(
+            test_object.test_object_type, test_object.test_object_name)
+        return web_element_wrapper.current_web_element
 
     def find_elements(self, test_object: TestObject):
         if self.current_webdriver is None:
             raise WebDriverIsNoneException(selenium_wrapper_web_driver_not_found_error)
-        return self.current_webdriver.find_elements(test_object.test_object_type, test_object.test_object_name)
+        web_element_wrapper.current_web_element = self.current_webdriver.find_elements(
+            test_object.test_object_type, test_object.test_object_name)
+        return web_element_wrapper.current_web_element
 
     def find_element_with_test_object_record(self, element_name: str):
         if self.current_webdriver is None:
@@ -124,5 +128,11 @@ class WebDriverWrapper(object):
     def wait_implicitly(self, time_to_wait: int):
         self.current_webdriver.implicitly_wait(time_to_wait)
 
+    def check_current_webdriver(self, check_dict: dict):
+        check_result(self.current_webdriver, check_dict)
+
+    def quit(self):
+        self.current_webdriver.quit()
+
 
 webdriver_wrapper = WebDriverWrapper()
